==> haskell-binary-tagged-0.1.4.2-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.4.2
id: binary-tagged-0.1.4.2-KMxMymOUT9FJ5ps7kVkx3u
key: binary-tagged-0.1.4.2-KMxMymOUT9FJ5ps7kVkx3u
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Tagged
abi: 024c68293a96e3008b70de1cc49890fc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/binary-tagged-0.1.4.2
hs-libraries: HSbinary-tagged-0.1.4.2-KMxMymOUT9FJ5ps7kVkx3u
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    aeson-1.0.2.1-FRh8NWzqPiiuj2q5G5H5S array-0.5.1.1 base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS binary-0.8.3.0
    bytestring-0.10.8.1 containers-0.5.7.1
    generics-sop-0.2.3.0-4LnlPExx4v7Lf51hjx2oHe
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    scientific-0.3.4.9-1EMxAMphVKV1cR2UEyLvhJ
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-tagged-0.1.4.2-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.4.2
id: binary-tagged-0.1.4.2-Leis0yRcGVA7DDqR92RpGa
key: binary-tagged-0.1.4.2-Leis0yRcGVA7DDqR92RpGa
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Tagged
abi: d245839d2c83999a9ec31d0fef17f0d8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/binary-tagged-0.1.4.2
hs-libraries: HSbinary-tagged-0.1.4.2-Leis0yRcGVA7DDqR92RpGa
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx array-0.5.1.1 base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS binary-0.8.3.0
    bytestring-0.10.8.1 containers-0.5.7.1
    generics-sop-0.2.4.0-8q0y0oRZNln24Ov1OYtww6
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
